<?php
/*
 * Plugin Name: Mimoza Yorumlar
 * Description: Web siteniz üzerinden kullanıcı yorumları ve yıldız derecelendirmeleri alıp yayınlamanızı sağlayan ücretsiz bir WordPress eklentisi.
 * Version: 1.0
 * Author: Mimoza Bilişim
 * Author URI: https://mimozabilisim.com/hakkimizda/
 * Plugin URI: https://mimozabilisim.com/wordpress-seo-eklentileri/
 * License: GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

// Yorumlar için özel içerik türü (Custom Post Type - CPT) oluştur
function mimoza_register_reviews_cpt() {
    $args = array(
        'labels' => array(
            'name' => 'Mimoza Yorumlar',
            'singular_name' => 'Yorum'
        ),
        'public' => true,
        'show_ui' => true,
        'has_archive' => false,
        'show_in_menu' => true,
        'menu_icon' => 'dashicons-testimonial',
        'supports' => array('title', 'editor', 'custom-fields'),
    );
    register_post_type('mimoza_review', $args);
}
add_action('init', 'mimoza_register_reviews_cpt');

// Gerekli scriptleri yükleme
add_action('wp_enqueue_scripts', 'mimoza_enqueue_scripts');
function mimoza_enqueue_scripts() {
    wp_enqueue_style('mimoza-styles', plugin_dir_url(__FILE__) . 'css/mimoza-style.css');
    wp_enqueue_script('google-recaptcha', 'https://www.google.com/recaptcha/api.js', array(), null, true);
    wp_enqueue_script('mimoza-ajax-script', plugin_dir_url(__FILE__) . 'js/mimoza-ajax.js', array('jquery'), null, true);
    wp_localize_script('mimoza-ajax-script', 'mimozaAjax', array('ajaxurl' => admin_url('admin-ajax.php')));
}

// Admin paneline eklenti ayarları ekleme
add_action('admin_menu', 'mimoza_add_settings_menu');
function mimoza_add_settings_menu() {
    add_menu_page('Mimoza Yorumlar', 'Yorum Ayarları', 'manage_options', 'mimoza-settings', 'mimoza_settings_page', 'dashicons-admin-generic', 25);
}

// Yorum formu için kısa kod
function mimoza_comment_form() {
    ob_start();
    ?>
    <div class="mimoza-comment-container">
        <h2 class="mimoza-comment-title">Bizim İçin Yorum Yapar Mısınız?</h2>
        <form id="mimoza-comment-form">
            <input type="text" name="name" placeholder="Adınız" required>
            <input type="email" name="email" placeholder="E-posta" required>
            <textarea name="comment" placeholder="Yorumunuz" required></textarea>
            <input type="hidden" name="mimoza_comment_nonce" value="<?php echo wp_create_nonce('mimoza_comment_nonce'); ?>">
            <div class="g-recaptcha" data-sitekey="<?php echo esc_attr(get_option('mimoza_recaptcha_site')); ?>"></div>
            <button type="submit">Yorumu Gönder</button>
        </form>
        <div id="comment-message"></div>
    </div>
    <?php
    return ob_get_clean();
}
add_shortcode('mimoza_comment_form', 'mimoza_comment_form');

// AJAX ile yorum gönderme işlemi
add_action('wp_ajax_nopriv_mimoza_submit_comment', 'mimoza_submit_comment');
add_action('wp_ajax_mimoza_submit_comment', 'mimoza_submit_comment');

function mimoza_submit_comment() {
    check_ajax_referer('mimoza_comment_nonce', 'security');

    $user_ip = $_SERVER['REMOTE_ADDR'];
    $blocked_ips = get_option('mimoza_blocked_ips', '');

    if (!empty($blocked_ips)) {
        $blocked_ips_array = array_map('trim', explode(',', $blocked_ips));
        if (in_array($user_ip, $blocked_ips_array)) {
            wp_send_json_error(['message' => 'Yorum yapma yetkiniz engellenmiştir.']);
            wp_die();
        }
    }

    $name = sanitize_text_field($_POST['name']);
    $email = sanitize_email($_POST['email']);
    $comment = sanitize_textarea_field($_POST['comment']);

    if (empty($name) || empty($comment)) {
        wp_send_json_error(['message' => 'Lütfen tüm alanları doldurun.']);
        wp_die();
    }

    $post_id = wp_insert_post(array(
        'post_title'   => wp_strip_all_tags($name . " Yorumu"),
        'post_content' => $comment,
        'post_status'  => 'pending',
        'post_type'    => 'mimoza_review',
        'post_author'  => get_current_user_id() ? get_current_user_id() : 1,
        'post_date'    => current_time('mysql'),
    ));

    if (!is_wp_error($post_id)) {
        wp_send_json_success(['message' => 'Yorumunuz başarıyla gönderildi ve onay bekliyor.']);
    } else {
        wp_send_json_error(['message' => 'Yorum gönderilirken hata oluştu.']);
    }
    wp_die();
}

// Admin paneli ayarlarını kaydetme
add_action('admin_init', 'mimoza_register_settings');
function mimoza_register_settings() {
    register_setting('mimoza_settings_group', 'mimoza_recaptcha_site');
    register_setting('mimoza_settings_group', 'mimoza_recaptcha_secret');
    register_setting('mimoza_settings_group', 'mimoza_blocked_ips');
}

// Admin paneli ayar sayfası
function mimoza_settings_page() {
    ?>
    <div class="wrap">
        <h1>Mimoza Yorumlar Ayarları</h1>
        <p>Google reCAPTCHA anahtarlarınızı almak için <a href="https://www.google.com/recaptcha/admin/create" target="_blank">buraya tıklayın</a>.</p>
        <form method="post" action="options.php">
            <?php
            settings_fields('mimoza_settings_group');
            do_settings_sections('mimoza-settings');
            ?>
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="mimoza_recaptcha_site">reCAPTCHA Site Key</label></th>
                    <td><input type="text" name="mimoza_recaptcha_site" id="mimoza_recaptcha_site" value="<?php echo esc_attr(get_option('mimoza_recaptcha_site')); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="mimoza_recaptcha_secret">reCAPTCHA Secret Key</label></th>
                    <td><input type="text" name="mimoza_recaptcha_secret" id="mimoza_recaptcha_secret" value="<?php echo esc_attr(get_option('mimoza_recaptcha_secret')); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><label for="mimoza_blocked_ips">Engellenmiş IP Adresleri</label></th>
                    <td><textarea name="mimoza_blocked_ips" id="mimoza_blocked_ips" rows="5" cols="50"><?php echo esc_textarea(get_option('mimoza_blocked_ips', '')); ?></textarea></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Kullanıcı yorumlarını listeleyen kısa kod
function mimoza_display_reviews() {
    $args = array(
        'post_type'      => 'mimoza_review',
        'post_status'    => 'publish',
        'posts_per_page' => 10,
    );

    $reviews = new WP_Query($args);

    if ($reviews->have_posts()) {
        ob_start();
        echo '<div class="mimoza-reviews">';
        echo '<h2 class="mimoza-review-title">Değerli Kullanıcılarımızın Yorumları</h2>';
        while ($reviews->have_posts()) {
            $reviews->the_post();
            echo '<div class="mimoza-review">';
            echo '<h3>' . esc_html(get_the_title()) . '</h3>';
            echo '<p>' . esc_html(get_the_content()) . '</p>';
            echo '</div>';
        }
        echo '</div>';
        wp_reset_postdata();
        return ob_get_clean();
    } else {
        return '<p>Henüz yorum bulunmamaktadır.</p>';
    }
}
add_shortcode('mimoza_reviews', 'mimoza_display_reviews');

add_action('wp_footer', 'mimoza_ajax_script');
function mimoza_ajax_script() {
    ?>
    <script>
        jQuery(document).ready(function($) {
            $('#mimoza-comment-form').on('submit', function(e) {
                e.preventDefault(); // Sayfa yenilemeyi durdur

                var formData = {
                    action: 'mimoza_submit_comment',
                    security: $('input[name="mimoza_comment_nonce"]').val(),
                    name: $('input[name="name"]').val(),
                    email: $('input[name="email"]').val(),
                    comment: $('textarea[name="comment"]').val(),
                    'g-recaptcha-response': grecaptcha.getResponse()
                };

                $.post(mimozaAjax.ajaxurl, formData, function(response) {
                    if (response.success) {
                        $('#comment-message').html('<p style="color: green;">' + response.data.message + '</p>');
                        $('#mimoza-comment-form')[0].reset();
                        grecaptcha.reset();
                    } else {
                        $('#comment-message').html('<p style="color: red;">' + response.data.message + '</p>');
                    }
                }).fail(function(xhr) {
                    console.error("AJAX Error: ", xhr.responseText);
                });
            });
        });
    </script>
    <?php
}

